==> deepin-calculator_5.7.12.orig.tar.gz: deepin-calculator-5.7.12/translations/deepin-calculator_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Nieprawidłowe wyrażenie</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Wyczyść całą pamięć</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Wyczyść historię</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Zaznacz wszystko</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Ponów</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Wytnij</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Kalkulator</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Standardowy</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Naukowy</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tryb</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>Kalkulator jest łatwym w użyciu kalkulatorem desktopowym, wspierającym trzy tryby: standardowy, naukowy i programisty.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>Programista</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Wyczyść element pamięci</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Wyczyść całą pamięć</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Przywołanie pamięci</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Dodaj do elementu pamięci</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Dodaj pamięć</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Odejmij od elementu pamięci</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Odejmowanie pamięci</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Sklep z pamięcią</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Pamięć</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Wyczyść element pamięci</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Dodaj do elementu pamięci</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Odejmij od elementu pamięci</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>Nic nie zostało zapisane w pamięci</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Nieprawidłowe wyrażenie</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Przesunięcie arytmetyczne</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Przesunięcie logiczne</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Przesunięcie cykliczne</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Zastosuj przesunięcie cykliczne</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Przesunięcie arytmetyczne</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Przesunięcie logiczne</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Przesunięcie cykliczne</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Zastosuj przesunięcie cykliczne</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Kalkulator</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Błąd wyrażenia</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Pamięć</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Błąd wyrażenia</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>Brak historii</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
</TS>

==> deepin-calculator_6.5.4.orig.tar.gz: deepin-calculator-6.5.4/translations/deepin-calculator_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Nieprawidłowe wyrażenie</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Wyczyść całą pamięć</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Wyczyść historię</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Zaznacz wszystko</translation>
    </message>
    <message>
        <source>Use thousands separator</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use ten-thousands separator</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Ponów</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Wytnij</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Kalkulator</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Standardowy</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Naukowy</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tryb</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>Kalkulator jest łatwym w użyciu kalkulatorem desktopowym, wspierającym trzy tryby: standardowy, naukowy i programisty.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>Programisty</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Wyczyść element pamięci</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Wyczyść całą pamięć</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Przywołanie pamięci</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Dodaj do elementu pamięci</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Dodaj pamięć</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Odejmij od elementu pamięci</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Odejmowanie pamięci</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Sklep z pamięcią</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Pamięć</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Wyczyść element pamięci</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Dodaj do elementu pamięci</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Odejmij od elementu pamięci</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>Nic nie zostało zapisane w pamięci</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Błąd wyrażenia</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Przesunięcie arytmetyczne</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Przesunięcie logiczne</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Przesunięcie cykliczne</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Zastosuj przesunięcie cykliczne</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Przesunięcie arytmetyczne</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Przesunięcie logiczne</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Przesunięcie cykliczne</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Zastosuj przesunięcie cykliczne</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Kalkulator</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Błąd wyrażenia</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Pamięć</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Błąd wyrażenia</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>Brak historii</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
</TS>
